@@ -128,12 +128,12 @@ async def git_pre_pull_and_push_to_all_remote_C(dirs: list[PathLike],
     dirs_s = list(map(str, dirs))
     if not any(status_codes):
         print(
-            f'✅ Pushed {"current branch" if branch is None else branch} of {dirs} to all of their remotes successfully.'
+            f'✅ Pushed {"current branch" if branch is None else branch} of {dirs_s} to all of their remotes successfully.'
             + ('(FORCE)' if force else ''))
         return 0
     else:
         print(
-            f'❌ Failed to push {"current branch" if branch is None else branch} of {dirs} to all of their remotes.'
+            f'❌ Failed to push {"current branch" if branch is None else branch} of {dirs_s} to all of their remotes.'
             + ('(FORCE)' if force else ''))
         return 1
     #     # all 0
